@@ -28,9 +28,14 @@ class GenericProfilerTest(unittest.TestCase):
 
     @patch.object(Uploader, 'upload_profile')
     def test_profile_step(self, mocked_upload_profile):
-        with profile_step(phase_name='training', ensure_profile=True):
+        def slow_method():
             time.sleep(0.1)
 
+        graphsignal.profilers.generic._profiler._exclude_path = 'donotmatchpath'
+        with profile_step(phase_name='training', ensure_profile=True):
+            slow_method()
+            slow_method()
+
         profile = mocked_upload_profile.call_args[0][0]
 
         #pp = pprint.PrettyPrinter()
@@ -39,3 +44,10 @@ class GenericProfilerTest(unittest.TestCase):
         self.assertEqual(profile.phase_name, 'training')
         self.assertTrue(profile.step_stats.step_count > 0)
         self.assertTrue(profile.step_stats.total_time_us > 0)
+
+        foundOp = False
+        for op_stats in profile.op_stats:
+            if op_stats.op_name.startswith('slow_method') and op_stats.count == 2 and op_stats.total_host_time_us > 200000:
+                foundOp = True
+                break
+        self.assertTrue(foundOp)
